pyLBM.boundary.Boundary
=======================

.. currentmodule:: pyLBM.boundary

.. autoclass:: Boundary

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      



   

